@@ -9,17 +9,22 @@ Implements new cred things for words.
 
 How does this thing work?
 
-1) Network connection on some port expecting to speak some protocol
-2) Protocol-specific authentication, resulting in some kind of credentials object
-3) twisted.cred.portal login using those credentials for the interface
-   IUser and with something implementing IChatClient as the mind
-4) successful login results in an IUser avatar the protocol can
-   call methods on, and state added to the realm such that the mind
-   will have methods called on it as is necessary
-5) protocol specific actions lead to calls onto the avatar; remote
-   events lead to calls onto the mind
-6) protocol specific hangup, realm is notified, user is removed
-   from active play, the end.
+  - Network connection on some port expecting to speak some protocol
+
+  - Protocol-specific authentication, resulting in some kind of credentials object
+
+  - twisted.cred.portal login using those credentials for the interface
+    IUser and with something implementing IChatClient as the mind
+
+  - successful login results in an IUser avatar the protocol can call
+    methods on, and state added to the realm such that the mind will have
+    methods called on it as is necessary
+
+  - protocol specific actions lead to calls onto the avatar; remote events
+    lead to calls onto the mind
+
+  - protocol specific hangup, realm is notified, user is removed from active
+    play, the end.
 """
 
 from time import time, ctime
@@ -28,10 +33,9 @@ from zope.interface import implements
 
 from twisted.words import iwords, ewords
 
-from twisted.python.components import registerAdapter, backwardsCompatImplements
-from twisted.cred import portal, credentials
+from twisted.python.components import registerAdapter
+from twisted.cred import portal, credentials, error as ecred
 from twisted.spread import pb
-from twisted.web import resource
 from twisted.words.protocols import irc
 from twisted.internet import defer, protocol
 from twisted.python import log, failure, reflect
@@ -122,8 +126,6 @@ class Group(object):
     def iterusers(self):
         # XXX Deferred?
         return iter(self.users.values())
-backwardsCompatImplements(Group)
-
 
 
 class User(object):
@@ -170,7 +172,6 @@ class User(object):
     def logout(self):
         for g in self.groups[:]:
             self.leave(g)
-backwardsCompatImplements(User)
 
 
 NICKSERV = 'NickServ!NickServ@services'
@@ -388,11 +389,18 @@ class IRCUser(irc.IRC):
                 NICKSERV,
                 nickname,
                 "Already logged in.  No pod people allowed!")
-        else:
+        elif err.check(ecred.UnauthorizedLogin):
             self.privmsg(
                 NICKSERV,
                 nickname,
                 "Login failed.  Goodbye.")
+        else:
+            log.msg("Unhandled error during login:")
+            log.err(err)
+            self.privmsg(
+                NICKSERV,
+                nickname,
+                "Server error during login.  Sorry.")
         self.transport.loseConnection()
 
 
@@ -619,7 +627,7 @@ class IRCUser(irc.IRC):
             # No group?  Fine, no names!
             self.names(
                 self.name,
-                '#' + group.name,
+                '#' + channel,
                 [])
 
         self.realm.lookupGroup(channel).addCallbacks(cbGroup, ebGroup)
@@ -680,7 +688,7 @@ class IRCUser(irc.IRC):
 
             def ebSet(err):
                 self.sendMessage(
-                    ERR_CHANOPRIVSNEEDED,
+                    irc.ERR_CHANOPRIVSNEEDED,
                     "#" + group.name,
                     ":You need to be a channel operator to do that.")
 
@@ -845,7 +853,6 @@ class IRCUser(irc.IRC):
         Parameters: <name> <password>
         """
         self.sendMessage(irc.ERR_NOOPERHOST, ":O-lines not applicable")
-backwardsCompatImplements(IRCUser)
 
 
 class IRCFactory(protocol.ServerFactory):
@@ -909,7 +916,6 @@ class PBMindReference(pb.RemoteReference):
             PBGroup(self.realm, self.avatar, group),
             PBUser(self.realm, self.avatar, user),
             reason)
-backwardsCompatImplements(PBMindReference)
 pb.setUnjellyableForClass(PBMind, PBMindReference)
 
 
@@ -949,7 +955,6 @@ class PBGroupReference(pb.RemoteReference):
 
     def send(self, message):
         return self.callRemote("send", message)
-backwardsCompatImplements(PBGroupReference)
 pb.setUnjellyableForClass(PBGroup, PBGroupReference)
 
 class PBUser(pb.Referenceable):
@@ -985,7 +990,6 @@ class ChatAvatar(pb.Referenceable):
         d.addCallback(cbGroup)
         return d
 registerAdapter(ChatAvatar, iwords.IUser, pb.IPerspective)
-backwardsCompatImplements(ChatAvatar)
 
 class AvatarReference(pb.RemoteReference):
     def join(self, groupName):
@@ -1026,7 +1030,8 @@ class WordsRealm(object):
 
 
     def requestAvatar(self, avatarId, mind, *interfaces):
-        assert isinstance(avatarId, str)
+        if isinstance(avatarId, str):
+            avatarId = avatarId.decode(self._encoding)
 
         def gotAvatar(avatar):
             if avatar.realm is not None:
@@ -1041,7 +1046,6 @@ class WordsRealm(object):
                     return iface, facet, self.logoutFactory(avatar, facet)
             raise NotImplementedError(self, interfaces)
 
-        avatarId = avatarId.decode(self._encoding)
         return self.getUser(avatarId).addCallback(gotAvatar)
 
 
@@ -1049,7 +1053,7 @@ class WordsRealm(object):
     createGroupOnRequest = False
     createUserOnRequest = True
 
-    def lookupGroup(self, name):
+    def lookupUser(self, name):
         raise NotImplementedError
 
 
@@ -1136,7 +1140,6 @@ class WordsRealm(object):
         d.addCallbacks(cbLookup, ebLookup)
         d.addCallback(self.addGroup)
         return d
-backwardsCompatImplements(WordsRealm)
 
 
 class InMemoryWordsRealm(WordsRealm):
@@ -1158,7 +1161,7 @@ class InMemoryWordsRealm(WordsRealm):
 
 
     def addGroup(self, group):
-        if group.name in self.users:
+        if group.name in self.groups:
             return defer.fail(failure.Failure(ewords.DuplicateGroup()))
         self.groups[group.name] = group
         return defer.succeed(group)
